Integrates the `webassets`_ library with Django, adding support for
merging, minifying and compiling CSS and Javascript files.

Documentation:
    http://django-assets.readthedocs.org/

.. _webassets: http://github.com/miracle2k/webassets
